#!/bin/bash

HOME=/usr/local/adminbcm
HOMELEN=${#HOME}
INSTALLPROG=$1

installbcmservice()
{
	SERVICENAME=$1
	SERVICEOFF=$2
	if [ -x $HOME/etc/init.d/$SERVICENAME ];then
		ln -sf $HOME/etc/init.d/$SERVICENAME /etc/init.d/$SERVICENAME
		chkconfig --del $SERVICENAME 2>/dev/null
		chkconfig --add $SERVICENAME
		if [ "$SERVICEOFF" == "off" ];then
			chkconfig $SERVICENAME off
		else
			chkconfig --level 345 $SERVICENAME on
		fi
	elif [ -L /etc/init.d/$SERVICENAME ];then
		chkconfig --del $SERVICENAME 2>/dev/null
		rm -f /etc/rc.d/rc?.d/???$SERVICENAME
		rm -f /etc/init.d/$SERVICENAME
	fi
}
installservice()
{
	SERVICENAME=$1
	FUNC=$2
	if [ -x /etc/init.d/$SERVICENAME ];then
		chkconfig --del $SERVICENAME >/dev/null 2>&1
		chkconfig --add $SERVICENAME >/dev/null 2>&1
		chkconfig --level 345 $SERVICENAME on
		if [ ! -z "$FUNC" ];then
			service $SERVICENAME $FUNC
		fi
	elif [ -f /usr/lib/systemd/system/$SERVICENAME.service ];then
		/usr/bin/systemctl enable $SERVICENAME >/dev/null 2>&1
		if [ ! -z "$FUNC" ];then
			/usr/bin/systemctl $FUNC $SERVICENAME
		fi
	fi
}
checklink()
{
	file=$1
	if [ ! -z "$file" ];then
		if [ -L "$file" ]; then
			if [ ! -e "$file" ];then
				dest=`readlink $file`
				if [ "${dest:0:$HOMELEN}" == "$HOME" ];then
					rm -f $file
				fi
			fi
		fi
	fi
}
checklinksdir()
{
	for i in $1/*;do
		checklink $i
	done
}
checklinks()
{
	checklinksdir /usr/local/bin
	checklinksdir /etc/cron.d
	checklinksdir /etc/logrotate.d
}
createlinksdir()
{
	COMP=$1
	ORIG=$2
	DEST=$3
	for i in $ORIG/*;do
		if [ -$COMP "$i" ];then
			ln -sf $i $DEST/
		fi
	done
}
createlinks()
{
	createlinksdir x $HOME/scripts/bin /usr/local/bin
	createlinksdir f $HOME/etc/cron.d /etc/cron.d
	createlinksdir f $HOME/etc/logrotate.d /etc/logrotate.d
}
if [ ! -d $HOME ];then
	exit 1
fi
installbcmservice adminbcmfw
installbcmservice adminbcmfw-setring
installbcmservice adminbcm-pppoe
installbcmservice adminbcm-pppoepromisc off
checklinks
createlinks
if [ ! -f /var/log/adminbcm.log ];then
	touch /var/log/adminbcm.log
fi
if [ -x $HOME/home/nodo.php ];then
	$HOME/home/nodo.php
fi
#base
if [ "$INSTALLPROG" == "base" ];then
	if [ ! -f /etc/my.cnf.d/adminbcm.cnf -a -d /etc/my.cnf.d/ ]; then
		echo "[mysqld]" > /etc/my.cnf.d/adminbcm.cnf
		echo "max_connections=1000" >> /etc/my.cnf.d/adminbcm.cnf
	fi
	installservice mysqld start
	installservice mariadb start
	$HOME/scripts/install/crearbasebcm.php
	$HOME/scripts/install/actualizarbasebcm.php
	$HOME/home/datosnodo.php
fi;
#bcm
if [ "$INSTALLPROG" == "bcm" ];then
	installservice radiusd
	#agrego las dependencias correctas en centos 7
	if [ -d /etc/systemd/system/ ];then
		mkdir /etc/systemd/system/radiusd.service.d/ >/dev/null 2>&1
		cat >/etc/systemd/system/radiusd.service.d/override.conf <<__EOF__
[Unit]
After=mariadb.service
__EOF__
		/usr/bin/systemctl daemon-reload >/dev/null 2>&1
	fi
	installservice pmacct
	installbcmservice adminbcmfw-daemon
	/etc/init.d/adminbcmfw-daemon restart
	#limpio las sesiones
	#/bin/rm -f /var/lib/php/session/sess_* >/dev/null 2>&1
	#config rsyslog para arpwatch
	syslogfile=/etc/rsyslog.conf
	syslogdir=/etc/rsyslog.d
	if [ ! -d $syslogdir ];then
		mkdir $syslogdir >/dev/null 2>&1
		chmod 755 $syslogdir
	fi
	incl=`cat $syslogfile | grep "$syslogdir"`
	if [ -z "$incl" ];then
		/bin/sed -i "s/imuxsock/imuxsock\n\n\$IncludeConfig\ \/etc\/rsyslog.d\/*.conf/g" $syslogfile
	fi
fi;
#mail
if [ "$INSTALLPROG" == "mail" ];then
	installservice mysqld start
	installservice mariadb start
	installservice mailgraph start
	$HOME/scripts/install/crearbasemail.php
	$HOME/scripts/install/actualizarbasemail.php
	if [ -d /usr/share/mailgraph ];then
		ln -f -s --no-target-directory /usr/share/mailgraph/ ${HOME}/home/mailgraph
	fi
fi;
#dns
if [ "$INSTALLPROG" == "dns" ];then
	if [ -f /usr/lib/systemd/system/named-chroot.service ];then
		/usr/bin/systemctl stop named >/dev/null 2>&1
		/usr/bin/systemctl disable named >/dev/null 2>&1
		installservice named-chroot
	else
		installservice named
	fi
	rm -f ${HOME}/tmp/dnsupdate
	/bin/chmod g+w /var/named/chroot/var/named/ >/dev/null 2>&1
fi;
#home
if [ "$INSTALLPROG" == "home" ];then
	if [ ! -f /etc/modprobe.d/adminbcm.conf ]; then
		echo "install nf_nat_sip /bin/true" > /etc/modprobe.d/adminbcm.conf
		echo "install nf_conntrack_sip /bin/true" >> /etc/modprobe.d/adminbcm.conf
		echo "install nf_nat_h323 /bin/true" >> /etc/modprobe.d/adminbcm.conf
		echo "install nf_conntrack_h323 /bin/true" >> /etc/modprobe.d/adminbcm.conf
		echo "install nf_nat_tftp /bin/true" >> /etc/modprobe.d/adminbcm.conf
		echo "install nf_conntrack_tftp /bin/true" >> /etc/modprobe.d/adminbcm.conf
		echo "install nf_nat_pptp /bin/true" >> /etc/modprobe.d/adminbcm.conf
		echo "install nf_conntrack_pptp /bin/true" >> /etc/modprobe.d/adminbcm.conf
		echo "install nf_nat_irc /bin/true" >> /etc/modprobe.d/adminbcm.conf
		echo "install nf_conntrack_irc /bin/true" >> /etc/modprobe.d/adminbcm.conf
		echo "install nf_nat_amanda /bin/true" >> /etc/modprobe.d/adminbcm.conf
		echo "install nf_conntrack_amanda /bin/true" >> /etc/modprobe.d/adminbcm.conf
		echo "install nf_nat_ftp /bin/true" >> /etc/modprobe.d/adminbcm.conf
		echo "install nf_conntrack_ftp /bin/true" >> /etc/modprobe.d/adminbcm.conf
		echo "options nf_conntrack hashsize=524288" >> /etc/modprobe.d/adminbcm.conf
	fi
	if [ ! -f /etc/modprobe.d/adminbcm_xt.conf ]; then
		echo "options xt_recent ip_list_tot=2048" > /etc/modprobe.d/adminbcm_xt.conf
	fi
	/bin/sed -i 's/port=10000/port=9999/g;/listen=1000/d' /etc/webmin/miniserv.conf >/dev/null 2>&1
	if [ -f ${HOME}/etc/lighttpd/lighttpd.conf ] && [ -d /etc/lighttpd ]; then
		ln -f -s ${HOME}/etc/lighttpd/lighttpd.conf /etc/lighttpd/lighttpd.conf
	fi
	rm -f ${HOME}/home/phpsysinfo
	installservice lighttpd restart
	#generar los graficos
	php -f ${HOME}/home/restartconfig.php >/dev/null 2>&1
	echo "expose_php = Off" > /etc/php.d/adminbcm_expose_off.ini
	echo "TraceEnable off"  > /etc/httpd/conf.d/adminbcm_traceoff.conf
	if [ ! -f "/etc/php.d/adminbcm_timezone.ini" ];then
		echo "[Date]" >/etc/php.d/adminbcm_timezone.ini
		echo "date.timezone=America/Argentina/Buenos_Aires" >>/etc/php.d/adminbcm_timezone.ini
	fi
	echo "post_max_size = 16M" > /etc/php.d/adminbcm_post.ini
	echo "max_input_vars = 2000" >> /etc/php.d/adminbcm_post.ini
fi
#pppoe
checklink /etc/ppp/ip-up.local
checklink /etc/ppp/ip-down.local
if [ "$INSTALLPROG" == "pppoe" ];then
	if [ -x $HOME/clients/ppp/ip-up.local.php -a -d /etc/ppp/ ];then
		ln -sf $HOME/clients/ppp/ip-up.local.php /etc/ppp/ip-up.local
		ln -sf $HOME/clients/ppp/ip-up.local.php /etc/ppp/ip-down.local
		echo 10.255.0.2-254 >/etc/ppp/ips
		echo 10.255.1.2-254 >>/etc/ppp/ips
		echo 10.255.2.2-254 >>/etc/ppp/ips
		echo 10.255.3.2-254 >>/etc/ppp/ips
		echo 10.255.4.2-254 >>/etc/ppp/ips
		echo 10.255.5.2-254 >>/etc/ppp/ips
		echo 10.255.6.2-254 >>/etc/ppp/ips
		echo 10.255.7.2-254 >>/etc/ppp/ips
		echo 10.255.8.2-254 >>/etc/ppp/ips
		echo 10.255.9.2-254 >>/etc/ppp/ips
		echo 10.255.10.2-254 >>/etc/ppp/ips
		echo 10.255.11.2-254 >>/etc/ppp/ips
		echo 10.255.12.2-254 >>/etc/ppp/ips
		echo 10.255.13.2-254 >>/etc/ppp/ips
		echo 10.255.14.2-254 >>/etc/ppp/ips
		echo 10.255.15.2-254 >>/etc/ppp/ips
		#echo 10.255.16.2-254 >>/etc/ppp/ips
		#echo 10.255.17.2-254 >>/etc/ppp/ips
		#echo 10.255.18.2-254 >>/etc/ppp/ips
		#echo 10.255.19.2-254 >>/etc/ppp/ips
		#echo 10.255.20.2-254 >>/etc/ppp/ips
		#echo 10.255.21.2-254 >>/etc/ppp/ips
		#echo 10.255.22.2-254 >>/etc/ppp/ips
		#echo 10.255.23.2-254 >>/etc/ppp/ips
		#echo 10.255.24.2-254 >>/etc/ppp/ips
		#echo 10.255.25.2-254 >>/etc/ppp/ips
		#echo 10.255.26.2-254 >>/etc/ppp/ips
		#echo 10.255.27.2-254 >>/etc/ppp/ips
		#echo 10.255.28.2-254 >>/etc/ppp/ips
		#echo 10.255.29.2-254 >>/etc/ppp/ips
		#echo 10.255.30.2-254 >>/etc/ppp/ips
		#echo 10.255.31.2-254 >>/etc/ppp/ips
	fi
	if [ ! -f "/etc/sysconfig/adminbcm-pppoe" ];then
		echo '#Service Name' >>/etc/sysconfig/adminbcm-pppoe
		echo '#SER="servicename1 servicename2"' >>/etc/sysconfig/adminbcm-pppoe
		echo '#Placas' >>/etc/sysconfig/adminbcm-pppoe
		echo '#ETH="eth1 eth2 eth3"' >>/etc/sysconfig/adminbcm-pppoe
		echo '#Access Control Name' >>/etc/sysconfig/adminbcm-pppoe
		echo '#ACN="MyServer1"' >>/etc/sysconfig/adminbcm-pppoe
		echo '#Max Sessions' >>/etc/sysconfig/adminbcm-pppoe
		echo '#MAX_SESSIONS=2' >>/etc/sysconfig/adminbcm-pppoe
		echo '#BRIDGE=1' >>/etc/sysconfig/adminbcm-pppoe
		echo '#USAR_IPV6=0' >>/etc/sysconfig/adminbcm-pppoe
		echo '#USAR_ACCEL=0' >>/etc/sysconfig/adminbcm-pppoe
		echo '#USAR_SHAPER=0' >>/etc/sysconfig/adminbcm-pppoe
		echo '#USAR_SNMP=0' >>/etc/sysconfig/adminbcm-pppoe
		echo '#USAR_SNMPMASTER=0' >>/etc/sysconfig/adminbcm-pppoe
		echo '#UNIT_CACHE=100' >>/etc/sysconfig/adminbcm-pppoe
		echo '#PADI_LIMIT_ACCEL=100' >>/etc/sysconfig/adminbcm-pppoe
		echo '#PADO_DELAY="0,50:500,60:750,70:1000,80:1250,100:1500,125:1750,150:2000,175:2500,200:3000"' >>/etc/sysconfig/adminbcm-pppoe
		echo '#DNS1=8.8.8.8' >>/etc/sysconfig/adminbcm-pppoe
		echo '#DNS2=8.8.4.4' >>/etc/sysconfig/adminbcm-pppoe
	fi
	FIRMACFG=`/usr/bin/sha1sum /etc/accel-ppp.conf.adminbcm 2>/dev/null | awk ' { print $1; } '`
	case "$FIRMACFG" in
		""|"31c4f2090597f4aaf907df9bf751ff864183938e"|"99f8361c16d94a6c1c3393cca4b1b83fa43ce3e7"|"34f8ee0765678d1684f504ec4f45eb65eeb63d61"|"7611714319a65e5e745c3aa305ead94cb2bdd5a6"|"1f3fccaf7b1aab46a0a99ed6267302503d86e572"|"71643e2d9649ee305ec7fdcfbf1c6bb23cb6a02a"|"940a667129b7ee1e78340a1b410b839762b8fb5c")
			/bin/cp -p $HOME/install/pppoe/etc/accel-ppp.conf.adminbcm /etc/accel-ppp.conf.adminbcm
		;;
		*)
		;;
	esac
	FIRMACFG=`/usr/bin/sha1sum /etc/snmp/accel-ppp.conf 2>/dev/null | awk ' { print $1; } '`
	case "$FIRMACFG" in
		"")
			/bin/cp -p $HOME/install/pppoe/etc/snmp/accel-ppp.conf /etc/snmp/accel-ppp.conf
		;;
		*)
		;;
	esac
fi
#hosting
httpddir=/etc/httpd
httpdconfdir=$httpddir/conf
httpdvirtualfile=httpd.virtual.conf
shellsfile=/etc/shells
shellftp=/bin/false
checklink $httpdconfdir/$httpdvirtualfile
if [ "$INSTALLPROG" == "hosting" ];then
	httpdfile=$httpdconfdir/httpd.conf
	basedir=`dirname $BASH_SOURCE`/hosting
	if [ -f $basedir/$httpdvirtualfile ];then
		ln -sf $basedir/$httpdvirtualfile $httpdconfdir/$httpdvirtualfile
		copiado=`cat $httpdfile | grep "$httpdvirtualfile"`
		if [ -z "$copiado" ];then
			echo "Include conf/httpd.virtual.conf" >>$httpdfile
		fi
	fi
	copiado=`cat $shellsfile | grep "$shellftp"`
	if [ -z "$copiado" ];then
		echo "$shellftp" >>$shellsfile
	fi
	sed -i 's/^anonymous_enable=YES$/anonymous_enable=NO/g' /etc/vsftpd/vsftpd.conf
	if [ ! -d $httpddir/conf.virtual.d ];then
		mkdir $httpddir/conf.virtual.d >/dev/null 2>&1
		chmod 755 $httpddir/conf.virtual.d
	fi
	installservice mysqld start
	installservice mariadb start
	$HOME/scripts/install/crearbasehosting.php
fi
#asterisk
if [ "$INSTALLPROG" == "asterisk" ];then
	installservice mysqld start
	installservice mariadb start
	$HOME/scripts/install/crearbaseasterisk.php
	$HOME/scripts/install/actualizarbaseasterisk.php
fi;
#uninstall
if [ "$INSTALLPROG" == "uninstall" ];then
	rm -f ${HOME}/home/phpsysinfo
fi
