#!/bin/bash

getuuid()
{
    local dev=$1
    local rv=`blkid  $dev -o value|grep '^........-....-....-....-............$'`
    echo "$rv"
}
clonaruuid()
{
    local orig=$1
    local dest=$2
    local part=$3
    uuid=$( getuuid /dev/${orig}${part} )
    if [ -n "$uuid" ];then
        fsck -fyC0 /dev/${dest}${part}
        flush
        echo $TUNEFS -U "$uuid" /dev/${dest}${part}
        $TUNEFS -U "$uuid" /dev/${dest}${part}
    fi
}
checkerr()
{
    local code=$1
    if [ $code -ne 0 ];then
        echo "error $code"
        exit $code
    fi
}
flush()
{
    sleep 1
    sync
    sleep 1
}
sincronizarpart()
{
    part=/dev/$1
    orig=$2
    dest=/mnt/000temp$1$RANDOM/
    echo "Rsync $orig"
    if [ ! -e $part ];then
        echo "$part no existe"
        exit -2
    fi
    umount $part 2>/dev/null
    flush
    mkdir $dest
    mount $part $dest
    checkerr $?
    mount 2>&1 |grep "^${part} .*type.ext3" -q && EXT3=$? || EXT3=$?
    if  [ $EXT3 -ne 0 ]; then
        fstrim -v $dest
        flush
    fi
    rsync -aHqAXx --delete --exclude '000temp*' $orig $dest
    syncerr=$?
    flush
    umount $part
    rmdir $dest
    checkerr $?
}
sincronizar()
{
    $TUNEFS -L/bootnew$RANDOM /dev/${discodest}1
    $TUNEFS -L/new$RANDOM /dev/${discodest}3
    syncerr=0
    sincronizarpart ${discodest}1 /boot/
    if [ $syncerr -eq 0 ];then
        sincronizarpart ${discodest}3 /
    fi
    $TUNEFS -L/boot /dev/${discodest}1
    $TUNEFS -L/ /dev/${discodest}3
    checkerr $syncerr
}
particionar()
{
cat <<EOF | fdisk /dev/${discodest}
p
d
3
n
p
3


w
EOF
}
versioncentos=`/bin/cat /etc/redhat-release 2>/dev/null |/bin/sed 's/.*release //g;s/\..*//g;s/[^0-9]//g'`
if [ 0$versioncentos -eq 5 ];then
    MKFS=mke4fs
    TUNEFS=tune4fs
    HASH_ALG=tea
    CLONAR_UUID=0
elif [ 0$versioncentos -eq 6 ] || [ 0$versioncentos -eq 7 ] || [ 0$versioncentos -eq 8 ];then
    MKFS=mke2fs
    TUNEFS=tune2fs
    HASH_ALG=half_md4
    CLONAR_UUID=1
else
    echo "Imposible determinar la version de centos"
    exit -2
fi
clear
cat /etc/fstab
fdisk -l
df -h
solosync=0
discoorig=sda
discodest=sdb
if [ -n "$DISCODEST" ];then
    discodest=$DISCODEST
elif [ -n "$1" ] ;then
    discodest=$1
fi
echo "DISCODEST=$discodest"
if [ ! -e /dev/${discodest} ];then
    echo "El disco de destino ${discodest} no existe"
    exit -1
fi
echo "1) Clonar particiones y sincronizar ${discodest}"
if [ -e /dev/${discodest}1 -a -e /dev/${discodest}3 ];then
    solosync=1
    echo "2) Solo sincronizar sin reparticionar ${discodest}"
fi
echo "*) Salir"
echo -n "Opcion: "

read opcion
if  [ "$opcion" == "1" ]; then
    echo "Ejecutar el clon"
    echo
    echo "Copiando tabla de particiones"
    dd if=/dev/${discoorig} of=/dev/${discodest} bs=512 count=2048
    checkerr $?
    flush
    if [ -z "$EXPANDPART" ] || [ 0$EXPANDPART -ne 0 ];then
        echo "Particionando el disco:"
        particionar
        flush
    fi
    echo "Recargo tabla de particiones"
    hdparm -z /dev/${discodest}
    checkerr $?
    flush
    echo "Genero swap"
    if [ 0$CLONAR_UUID ];then
        uuidswap=$( getuuid /dev/${discoorig}2 )
    fi
    if [ -n "$uuidswap" ];then
        uuidswap="-U $uuidswap"
    fi
    mkswap -L SWAP-sda2 ${uuidswap} /dev/${discodest}2
    echo "Clono ${discodest}1"
    mount -o remount,ro /dev/${discoorig}1
    dd if=/dev/${discoorig}1 of=/dev/${discodest}1 bs=1M
    mount -o remount,rw /dev/${discoorig}1
    flush
    fsck -fyC0 /dev/${discodest}1
    flush
    $TUNEFS -U random /dev/${discodest}1
    echo "Formateo ${discodest}3"
    $MKFS -t ext4 -j -L /new$RANDOM /dev/${discodest}3
    $TUNEFS -o acl,user_xattr /dev/${discodest}3
    $TUNEFS -E hash_alg=$HASH_ALG /dev/${discodest}3
    $TUNEFS -c -1 -i 0 /dev/${discodest}3
    flush
fi
if  [ "$opcion" == "1" ] || [ "$opcion" == "2"  -a "$solosync" == "1" ]; then
    sincronizar
    if [ 0$CLONAR_UUID ];then
        clonaruuid ${discoorig} ${discodest} 1
        clonaruuid ${discoorig} ${discodest} 3
    fi
    echo "Clon finalizado con exito"
    exit 0
fi
echo "Salir sin realizar el clon"
exit -1
